@@ -1,7 +1,7 @@
 use strict;
 package Yaadgom;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Moo;
 use Devel::GlobalDestruction;
 
@@ -81,7 +81,7 @@ sub _write_preformated {
     "<pre>$str\n</pre>\n";
 }
 
-sub format_response_body {
+sub format_body {
     my ( $self, $str ) = @_;
     my ( $header, $body ) = split /\n\n/, $str;
     if ( $header =~ /application\/json/ && $body ) {
@@ -89,7 +89,7 @@ sub format_response_body {
         $body = decode( 'utf8', $body );
     }
 
-    $self->call_trigger( 'format_response_body', { response_str => $body } );
+    $self->call_trigger( 'format_body', { response_str => $body } );
     my @results = @{ $self->last_trigger_results };
     $body = $results[-1] if $results[-1];
 
@@ -117,9 +117,9 @@ sub get_markdown {
       ( defined $file_name ? "<small>$file_name</small>\n" : '' ),
       ( exists $opt{extra}{name} ? ( $self->_write_line( '> ' . $opt{extra}{name} . "\n" ) ) : () ),
       $self->_write_subtitle('Request'),
-      $self->_write_preformated( $self->format_response_body( $req->as_string ) ),
+      $self->_write_preformated( $self->format_body( $req->as_string ) ),
       $self->_write_subtitle('Response'),
-      $self->_write_preformated( $self->format_response_body( $res->as_string ) );
+      $self->_write_preformated( $self->format_body( $res->as_string ) );
 
     do {
         $self->call_trigger( 'format_before_extras', { str => $str } );
@@ -253,7 +253,7 @@ Yaadgom - Yet Another Automatic Document Generator (On Markdown)
     # create an instance
     my $foo = Yaadgom->new;
 
-    # call this methoed each request you want to document
+    # call this method each request you want to document
     $foo->process_response(
         folder => 'test', # what 'folder' or 'category' this is
         weight => 1     , # default order
@@ -278,17 +278,17 @@ Yaadgom - Yet Another Automatic Document Generator (On Markdown)
 
 Yaadgom helps you document your requests (to create an API Reference or something like that).
 
-Yaadgom output string in markdown format, so you can use those generated files on http://daux.io or other tools.
+Yaadgom output string in markdown format, so you can use those generated files on http://daux.io or github
 
+For each time you call "process_response" it will generate a new section composed of:
 
-=begin HTML
-
-
-<p><img src="http://i.imgur.com/N6KbTew.png" width="915" height="954" alt="Real web page generated by Yaadgom and daux.io" /></p>
-
-
-=end HTML
-
+    ## Title with $desc
+    defined $file_name ? <small>$file_name</small>
+    exists $opt{extra}{name} ? > $opt{extra}{name}
+    ### Request
+    <pre> &format_body( $req->as_string ) </pre>
+    ### Response
+    <pre> &format_body( $res->as_string ) </pre>
 
 =head1 METHODS
 
@@ -328,7 +328,7 @@ Yaadgom output string in markdown format, so you can use those generated files o
 
 =head2 export_to_dir
 
-    # note that this do an append operation on files, so you may reset/truncate your dir before calling this.
+    # note that this do an append operation on files, so you may reset / truncate your directory before calling this.
     # this is done because you may want multiple tests writing to same file, in different moments.
     $self->export_to_dir(
         dir => '/tmp/
@@ -336,20 +336,20 @@ Yaadgom output string in markdown format, so you can use those generated files o
 
 =head1 Class::Trigger names
 
-On each trigger, the returning is used as the new version of the input. Except for process_extras, where all returnings are concatenated.
+On each trigger, return is used as the new version of the input. Except for *process_extras*, where all return are concatenated.
 
 
 Trigger / variables:
 
     $self0_01->call_trigger( 'filename_generated', { req => $req, file => $file } );
     $self0_01->call_trigger( 'format_title', { header => $desc } );
-    $self0_01->call_trigger( 'format_response_body', { response_str => $body } );
+    $self0_01->call_trigger( 'format_body', { response_str => $body } );
     $self0_01->call_trigger( 'format_before_extras', { str => $str } );
     $self0_01->call_trigger( 'format_after_extras', { str => $str } );
     $self0_01->call_trigger( 'process_extras', %opt );
     $self0_01->call_trigger( 'format_generated_str', { str => $format_time } );
 
-Updated @ Stash-REST 0.02
+Updated @ Stash-REST 0.03
 
     $ grep  '$self_0_01->call_trigger' lib/Yaadgom.pm  | perl -ne '$_ =~ s/^\s+//; $_ =~ s/self-/self0_01-/; print' | sort | uniq
 
@@ -372,6 +372,7 @@ Then, create some package that extends Stash::REST (you can call add_trigger on
 
     my $dir = $ENV{DAUX_OUTPUT_DIR};
 
+    # workarround for re-using same folder when Stash::REST call get and list of an created object.
     my $reuse_last_daux_top;
     my $reuse_count;
 
@@ -420,13 +421,22 @@ Now, after you run your script
         '/zuzus',
         name  => 'add zuzu',
         list  => 1,
-        stash => 'easyname',
         folder => 'SomeFolder',
         params => [ name => 'foo', ]
     );
 
 You should have on $ENV{DAUX_OUTPUT_DIR} a SomeFolder directory with zuzus.md inside.
 
+If you copy those .md files into daux.io/docs folder, you can build something like this:
+
+=begin HTML
+
+<p><img src="http://i.imgur.com/N6KbTew.png" width="915" height="954" alt="Real web page generated by Yaadgom and daux.io" /></p>
+
+
+=end HTML
+
+
 =head1 AUTHOR
 
 Renato CRON E<lt>rentocron@cpan.orgE<gt>
